@@ -288,6 +288,18 @@ func newEnvVars(nodeName, clusterName, instanceRam string, roleMap map[api.Elast
 				},
 			},
 		},
+		v1.EnvVar{
+			Name: "POD_IP",
+			ValueFrom: &v1.EnvVarSource{
+				FieldRef: &v1.ObjectFieldSelector{
+					FieldPath: "status.podIP",
+				},
+			},
+		},
+		v1.EnvVar{
+			Name:  "KUBERNETES_MASTER",
+			Value: "https://kubernetes.default.svc",
+		},
 		v1.EnvVar{
 			Name:  "KUBERNETES_TRUST_CERT",
 			Value: "true",
