@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"html/template"
 	"io"
-	"runtime"
 	"strconv"
 
 	"github.com/sirupsen/logrus"
@@ -32,7 +31,6 @@ type esYmlStruct struct {
 	EsUnicastHost         string
 	NodeQuorum            string
 	RecoverExpectedShards string
-	SystemCallFilter      string
 }
 
 type log4j2PropertiesStruct struct {
@@ -62,12 +60,11 @@ func (elasticsearchRequest *ElasticsearchRequest) CreateOrUpdateConfigMaps() (er
 		dpl.Labels,
 		kibanaIndexMode,
 		esUnicastHost(dpl.Name, dpl.Namespace),
-		rootLogger(),
+		rootLogger(elasticsearchRequest.cluster),
 		strconv.Itoa(masterNodeCount/2+1),
 		strconv.Itoa(dataNodeCount),
 		strconv.Itoa(dataNodeCount),
 		strconv.Itoa(calculateReplicaCount(dpl)),
-		strconv.FormatBool(runtime.GOARCH == "amd64"),
 	)
 
 	addOwnerRefToObject(configmap, getOwnerRef(dpl))
@@ -116,11 +113,11 @@ func (elasticsearchRequest *ElasticsearchRequest) CreateOrUpdateConfigMaps() (er
 	return nil
 }
 
-func renderData(kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount, systemCallFilter, rootLogger string) (error, map[string]string) {
+func renderData(kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount, rootLogger string) (error, map[string]string) {
 
 	data := map[string]string{}
 	buf := &bytes.Buffer{}
-	if err := renderEsYml(buf, kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, systemCallFilter); err != nil {
+	if err := renderEsYml(buf, kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards); err != nil {
 		return err, data
 	}
 	data[esConfig] = buf.String()
@@ -142,9 +139,9 @@ func renderData(kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShard
 
 // newConfigMap returns a v1.ConfigMap object
 func newConfigMap(configMapName, namespace string, labels map[string]string,
-	kibanaIndexMode, esUnicastHost, rootLogger, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount, systemCallFilter string) *v1.ConfigMap {
+	kibanaIndexMode, esUnicastHost, rootLogger, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount string) *v1.ConfigMap {
 
-	err, data := renderData(kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount, systemCallFilter, rootLogger)
+	err, data := renderData(kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, primaryShardsCount, replicaShardsCount, rootLogger)
 	if err != nil {
 		return nil
 	}
@@ -188,7 +185,7 @@ func configMapContentChanged(old, new *v1.ConfigMap) bool {
 	return false
 }
 
-func renderEsYml(w io.Writer, kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards, systemCallFilter string) error {
+func renderEsYml(w io.Writer, kibanaIndexMode, esUnicastHost, nodeQuorum, recoverExpectedShards string) error {
 	t := template.New("elasticsearch.yml")
 	config := esYmlTmpl
 	t, err := t.Parse(config)
@@ -200,7 +197,6 @@ func renderEsYml(w io.Writer, kibanaIndexMode, esUnicastHost, nodeQuorum, recove
 		EsUnicastHost:         esUnicastHost,
 		NodeQuorum:            nodeQuorum,
 		RecoverExpectedShards: recoverExpectedShards,
-		SystemCallFilter:      systemCallFilter,
 	}
 
 	return t.Execute(w, esy)
