@@ -4,9 +4,6 @@ const esYmlTmpl = `
 cluster:
   name: ${CLUSTER_NAME}
 
-bootstrap:
-  system_call_filter: {{.SystemCallFilter}}
-
 script:
   inline: true
   stored: true
@@ -18,7 +15,8 @@ node:
   max_local_storage_nodes: 1
 
 network:
-  host: 0.0.0.0
+  publish_host: ${POD_IP}
+  bind_host: ["${POD_IP}",_local_]
 
 discovery.zen:
   ping.unicast.hosts: {{.EsUnicastHost}}
@@ -44,9 +42,6 @@ openshift.searchguard:
 
 openshift.kibana.index.mode: {{.KibanaIndexMode}}
 
-prometheus:
-  indices: false
-
 path:
   data: /elasticsearch/persistent/${CLUSTER_NAME}/data
   logs: /elasticsearch/persistent/${CLUSTER_NAME}/logs
