@@ -3,7 +3,7 @@ package k8shandler
 import (
 	"fmt"
 
-	api "github.com/openshift/elasticsearch-operator/pkg/apis/elasticsearch/v1"
+	api "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 )
 
 const (
@@ -22,6 +22,10 @@ const (
 	elasticsearchCertsPath  = "/etc/openshift/elasticsearch/secret"
 	elasticsearchConfigPath = "/usr/share/java/elasticsearch/config"
 	heapDumpLocation        = "/elasticsearch/persistent/heapdump.hprof"
+
+	k8sTokenFile = "/var/run/secrets/kubernetes.io/serviceaccount/token"
+
+	logAppenderAnnotation = "elasticsearch.openshift.io/develLogAppender"
 )
 
 func kibanaIndexMode(mode string) (string, error) {
@@ -38,7 +42,10 @@ func esUnicastHost(clusterName, namespace string) string {
 	return fmt.Sprintf("%v-cluster.%v.svc", clusterName, namespace)
 }
 
-func rootLogger() string {
+func rootLogger(cluster *api.Elasticsearch) string {
+	if value, ok := cluster.GetAnnotations()[log4jConfig]; ok {
+		return value
+	}
 	return "rolling"
 }
 
