@@ -5,6 +5,9 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/openshift/elasticsearch-operator/pkg/logger"
+	"github.com/openshift/elasticsearch-operator/pkg/utils/comparators"
+
 	"github.com/sirupsen/logrus"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -78,8 +81,9 @@ func (current *statefulSetNode) updateReference(desired NodeTypeInterface) {
 }
 
 func (node *statefulSetNode) state() api.ElasticsearchNodeStatus {
-	var rolloutForReload v1.ConditionStatus
+	//var rolloutForReload v1.ConditionStatus
 	var rolloutForUpdate v1.ConditionStatus
+	var rolloutForCertReload v1.ConditionStatus
 
 	// see if we need to update the deployment object
 	if node.isChanged() {
@@ -102,15 +106,15 @@ func (node *statefulSetNode) state() api.ElasticsearchNodeStatus {
 	} else {
 		// check if the secretHash changed
 		if newSecretHash != node.secretHash {
-			rolloutForReload = v1.ConditionTrue
+			rolloutForCertReload = v1.ConditionTrue
 		}
 	}
 
 	return api.ElasticsearchNodeStatus{
 		StatefulSetName: node.self.Name,
 		UpgradeStatus: api.ElasticsearchNodeUpgradeStatus{
-			ScheduledForUpgrade:  rolloutForUpdate,
-			ScheduledForRedeploy: rolloutForReload,
+			ScheduledForUpgrade:      rolloutForUpdate,
+			ScheduledForCertRedeploy: rolloutForCertReload,
 		},
 	}
 }
@@ -238,7 +242,7 @@ func (node *statefulSetNode) isMissing() bool {
 	return false
 }
 
-func (node *statefulSetNode) restart(upgradeStatus *api.ElasticsearchNodeStatus) {
+func (node *statefulSetNode) rollingRestart(upgradeStatus *api.ElasticsearchNodeStatus) {
 
 	if upgradeStatus.UpgradeStatus.UnderUpgrade != v1.ConditionTrue {
 		if status, _ := GetClusterHealthStatus(node.clusterName, node.self.Namespace, node.client); status != "green" {
@@ -328,6 +332,74 @@ func (node *statefulSetNode) restart(upgradeStatus *api.ElasticsearchNodeStatus)
 	}
 }
 
+func (node *statefulSetNode) fullClusterRestart(upgradeStatus *api.ElasticsearchNodeStatus) {
+
+	if upgradeStatus.UpgradeStatus.UnderUpgrade != v1.ConditionTrue {
+		replicas, err := node.replicaCount()
+		if err != nil {
+			logrus.Warnf("Unable to get number of replicas prior to restart for %v", node.name())
+			return
+		}
+
+		size, err := GetClusterNodeCount(node.clusterName, node.self.Namespace, node.client)
+		if err != nil {
+			logrus.Warnf("Unable to get cluster size prior to restart for %v", node.name())
+			return
+		}
+
+		node.setPartition(replicas)
+		node.clusterSize = size
+		upgradeStatus.UpgradeStatus.UnderUpgrade = v1.ConditionTrue
+	}
+
+	if upgradeStatus.UpgradeStatus.UpgradePhase == "" ||
+		upgradeStatus.UpgradeStatus.UpgradePhase == api.ControllerUpdated {
+
+		// nothing to do here -- just maintaing a framework structure
+
+		upgradeStatus.UpgradeStatus.UpgradePhase = api.NodeRestarting
+	}
+
+	if upgradeStatus.UpgradeStatus.UpgradePhase == api.NodeRestarting {
+
+		ordinal, err := node.partition()
+		if err != nil {
+			logrus.Infof("Unable to get node ordinal value: %v", err)
+			return
+		}
+
+		for index := ordinal; index > 0; index-- {
+			// get podName based on ordinal index and node.name()
+			podName := fmt.Sprintf("%v-%v", node.name(), index-1)
+
+			// delete the pod
+			if err := DeletePod(podName, node.self.Namespace, node.client); err != nil {
+				logrus.Infof("Unable to delete pod %v for restart: %v", podName, err)
+				return
+			}
+
+			// wait for node to leave cluster
+			if err, _ := node.waitForNodeLeaveCluster(); err != nil {
+				logrus.Infof("Timed out waiting for %v to leave the cluster", podName)
+				return
+			}
+
+			// used for tracking in case of timeout
+			node.setPartition(index - 1)
+		}
+
+		node.refreshHashes()
+
+		upgradeStatus.UpgradeStatus.UpgradePhase = api.RecoveringData
+	}
+
+	if upgradeStatus.UpgradeStatus.UpgradePhase == api.RecoveringData {
+
+		upgradeStatus.UpgradeStatus.UpgradePhase = api.ControllerUpdated
+		upgradeStatus.UpgradeStatus.UnderUpgrade = ""
+	}
+}
+
 func (node *statefulSetNode) delete() {
 	node.client.Delete(context.TODO(), &node.self)
 }
@@ -556,6 +628,12 @@ func (node *statefulSetNode) isChanged() bool {
 			changed = true
 		}
 
+		if !comparators.EnvValueEqual(desiredContainer.Env, nodeContainer.Env) {
+			nodeContainer.Env = desiredContainer.Env
+			logger.Debugf("Container EnvVars are different between current and desired for %s", nodeContainer.Name)
+			changed = true
+		}
+
 		node.self.Spec.Template.Spec.Containers[index] = nodeContainer
 	}
 	return changed
